//
//  AppDelegate.m
//  BLMAdDemo
//
//  Created by BloomAd on 2022/6/19.
//

#import "AppDelegate.h"
#import <BLMAdSdk/BLMAdSdk.h>
#import <AppTrackingTransparency/AppTrackingTransparency.h>
#import "UIView+Utils.h"

static NSString * const kAppId = @"1100000000";
static const NSInteger kBottomViewHeight = 120;

@interface AppDelegate () <BLMSplashAdDelegate>

@property(strong, nonatomic) BLMSplashAdManager *splashAdManager;
@property(strong, nonatomic) UIView *launchScreenView;
@property(strong, nonatomic) UIView *bottomView;

@end

@implementation AppDelegate

- (BOOL)application:(UIApplication *)application didFinishLaunchingWithOptions:(NSDictionary *)launchOptions {
    // 初始化 window
    self.window = [[UIWindow alloc] initWithFrame:[UIScreen mainScreen].bounds];
    UIStoryboard *storyBoard = [UIStoryboard storyboardWithName:@"Main" bundle:nil];
    UIViewController *vc = [storyBoard instantiateInitialViewController];
    self.window.rootViewController = vc;
    [self.window makeKeyAndVisible];
    
    if (@available(iOS 14, *)) {
        // IDFA 权限申请
        [ATTrackingManager requestTrackingAuthorizationWithCompletionHandler:^(ATTrackingManagerAuthorizationStatus status) {
            [self setupAdsdk];
            [self loadSplashAd];
        }];
    } else {
        [self setupAdsdk];
        [self loadSplashAd];
    }

    return YES;
}

- (void)setupAdsdk {
    [BLMAdSdkManager setAppId:kAppId];
#ifdef DEBUG
    [BLMAdSdkManager setDebug:YES];
#else
    [BLMAdSdkManager setDebug:NO];
#endif
}

- (void)loadSplashAd {
    // 展示启动图
    [self.window addSubview:self.launchScreenView];
    
    // 加载开屏广告
    self.splashAdManager = [[BLMSplashAdManager alloc] initWithUnitId:@"s1"];
    self.splashAdManager.delegate = self;
    CGSize screenSize = [UIScreen mainScreen].bounds.size;
    [self.splashAdManager loadAdWithWidth:screenSize.width height:screenSize.height - kBottomViewHeight];
}

- (UIView *)launchScreenView {
    if (!_launchScreenView) {
        UIStoryboard *storyBoard = [UIStoryboard storyboardWithName:@"LaunchScreen" bundle:nil];
        UIViewController *vc = [storyBoard instantiateInitialViewController];
        _launchScreenView = vc.view;
    }
    return _launchScreenView;
}

- (UIView *)bottomView {
    if (!_bottomView) {
        CGSize screenSize = [UIScreen mainScreen].bounds.size;
        _bottomView = [[UIView alloc] initWithFrame:CGRectMake(0, screenSize.height - kBottomViewHeight, screenSize.width, kBottomViewHeight)];
        UIImageView *imageView = [[UIImageView alloc] initWithImage:[UIImage imageNamed:@"slogan"]];
        imageView.frame = CGRectMake(20, 20, _bottomView.width - 40, kBottomViewHeight - 40);
        imageView.contentMode = UIViewContentModeScaleAspectFit;
        [_bottomView addSubview:imageView];
    }
    return _bottomView;
}

#pragma mark - BLMSplashAdDelegate

- (void)splashAdDidLoad:(BLMSplashAd *)ad {
    NSLog(@"%s", __FUNCTION__);

    [ad showAdInView:self.launchScreenView withBottomView:self.bottomView];
}

- (void)splashAdFailToLoadWithError:(NSError *)error {
    NSLog(@"%s %@", __FUNCTION__, error);
    
    [self.launchScreenView removeFromSuperview];
    [self.splashAdManager cancelAll];
}

- (void)splashAdWillVisible:(BLMSplashAd *)ad {
    NSLog(@"%s", __FUNCTION__);
}

- (void)splashAdDidClick:(BLMSplashAd *)ad {
    NSLog(@"%s", __FUNCTION__);
}

- (void)splashAdDidClose:(BLMSplashAd *)ad {
    NSLog(@"%s", __FUNCTION__);
    
    [self.launchScreenView removeFromSuperview];
    [self.splashAdManager cancelAll];
}

- (void)splashAdDidFail:(BLMSplashAd *)ad error:(NSError *)error {
    NSLog(@"%s %@", __FUNCTION__, error);
    
    [self.launchScreenView removeFromSuperview];
    [self.splashAdManager cancelAll];
}

@end
