//
//  BannerViewController.m
//  BLMAdDemo
//
//  Created by BloomAd on 2022/7/4.
//

#import "BannerViewController.h"
#import <BLMAdSdk/BLMAdSdk.h>
#import <Toast/Toast.h>
#import "UIView+Utils.h"

@interface BannerViewController () <BLMBannerAdDelegate>

@property(strong, nonatomic) BLMBannerAdManager *bannerAdManager;
@property(strong, nonatomic) BLMBannerAd *bannerAd;
@property(nonatomic) CGRect bannerViewFrame;
@property(nonatomic) BOOL autoShow;

@end

@implementation BannerViewController

- (void)viewDidLoad {
    [super viewDidLoad];
    self.navigationItem.title = @"Banner 广告";
}

- (IBAction)loadBannerAd:(id)sender {
    [self loadBannerAdAutoShow:NO];
}

- (IBAction)showBannerAd:(id)sender {
    if (!self.bannerAd) {
        [self.view makeToast:@"广告未加载成功"];
    } else if (!self.bannerAd.isValid) {
        [self.view makeToast:@"广告无效，请重新加载"];
    } else {
        [self.view addSubview:self.bannerAd.view];
    }
}

- (IBAction)loadAndShowBannerAd:(id)sender {
    [self loadBannerAdAutoShow:YES];
}

- (void)loadBannerAdAutoShow:(BOOL)autoShow {
    self.autoShow = autoShow;
    
    self.bannerAdManager = [[BLMBannerAdManager alloc] initWithUnitId:@"b1"];
    self.bannerAdManager.delegate = self;
    CGFloat width = self.view.width - 40;
    CGFloat height = width * 100 / 640;
    self.bannerViewFrame = CGRectMake((self.view.width - width) / 2,
                                      self.view.height - height - 40,
                                      width,
                                      height);
    [self.bannerAdManager loadAdWithWidth:width height:height viewController:self];
}

#pragma mark - BLMBannerAdDelegate

- (void)bannerAdDidLoad:(BLMBannerAd *)ad {
    NSLog(@"%s", __FUNCTION__);
    [self.view makeToast:@"广告加载成功"];
    self.bannerAd = ad;
    self.bannerAd.view.frame = self.bannerViewFrame;

    if (self.autoShow) {
        [self.view addSubview:self.bannerAd.view];
    }
}

- (void)bannerAdFailToLoadWithError:(NSError *)error {
    NSLog(@"%s %@", __FUNCTION__, error);
    [self.view makeToast:[NSString stringWithFormat: @"%@", error]];
}

- (void)bannerAdWillVisible:(BLMBannerAd *)ad {
    NSLog(@"%s", __FUNCTION__);
}

- (void)bannerAdDidClick:(BLMBannerAd *)ad {
    NSLog(@"%s", __FUNCTION__);
}

- (void)bannerAdDidClose:(BLMBannerAd *)ad {
    NSLog(@"%s", __FUNCTION__);
}

- (void)bannerAdDidFail:(BLMBannerAd *)ad error:(NSError *)error {
    NSLog(@"%s %@", __FUNCTION__, error);
    [self.view makeToast:[NSString stringWithFormat: @"%@", error]];
}

@end
