//
//  InterstitialViewController.m
//  BLMAdDemo
//
//  Created by BloomAd on 2022/7/4.
//

#import "InterstitialViewController.h"
#import <BLMAdSdk/BLMAdSdk.h>
#import <Toast/Toast.h>
#import "UIView+Utils.h"

@interface InterstitialViewController () <BLMInterstitialAdDelegate>

@property(strong, nonatomic) BLMInterstitialAdManager *interstitialAdManager;
@property(strong, nonatomic) BLMInterstitialAd *interstitialAd;

@end

@implementation InterstitialViewController

- (void)viewDidLoad {
    [super viewDidLoad];
    self.navigationItem.title = @"插屏广告";
}

- (IBAction)loadInterstitialAd:(id)sender {
    [self loadInterstitialAdAutoShow:NO];
}

- (IBAction)showInterstitialAd:(id)sender {
    if (!self.interstitialAd) {
        [self.view makeToast:@"广告未加载成功"];
    } else if (!self.interstitialAd.isValid) {
        [self.view makeToast:@"广告无效，请重新加载"];
    } else {
        [self.interstitialAd showAdFromRootViewController:self];
    }
}

- (IBAction)loadAndShowInterstitialAd:(id)sender {
    [self loadInterstitialAdAutoShow:YES];
}

- (void)loadInterstitialAdAutoShow:(BOOL)autoShow {
    self.interstitialAdManager = [[BLMInterstitialAdManager alloc] initWithUnitId:@"i1"];
    self.interstitialAdManager.delegate = self;
    CGFloat width = self.view.width - 40;
    CGFloat height = width * 300 / 200;
    if (autoShow) {
        [self.interstitialAdManager loadAndShowAdFromRootViewController:self width:width height:height];
    } else {
        [self.interstitialAdManager loadAdWithWidth:width height:height];
    }
}

#pragma mark - BLMInterstitialAdDelegate

- (void)interstitialAdDidLoad:(BLMInterstitialAd *)ad {
    NSLog(@"%s", __FUNCTION__);
    [self.view makeToast:@"广告加载成功"];
    self.interstitialAd = ad;
}

- (void)interstitialAdFailToLoadWithError:(NSError *)error {
    NSLog(@"%s %@", __FUNCTION__, error);
    [self.view makeToast:[NSString stringWithFormat: @"%@", error]];
}

- (void)interstitialAdWillVisible:(BLMInterstitialAd *)ad {
    NSLog(@"%s", __FUNCTION__);
}

- (void)interstitialAdDidClick:(BLMInterstitialAd *)ad {
    NSLog(@"%s", __FUNCTION__);
}

- (void)interstitialAdDidClose:(BLMInterstitialAd *)ad {
    NSLog(@"%s", __FUNCTION__);
}

- (void)interstitialAdDidFail:(BLMInterstitialAd *)ad error:(NSError *)error {
    NSLog(@"%s %@", __FUNCTION__, error);
    [self.view makeToast:[NSString stringWithFormat: @"%@", error]];
}

@end
