//
//  NativeViewController.m
//  BLMAdDemo
//
//  Created by BloomAd on 2022/7/4.
//

#import "NativeViewController.h"
#import <BLMAdSdk/BLMAdSdk.h>
#import <Toast/Toast.h>
#import "UIView+Utils.h"

@interface NativeViewController () <BLMNativeAdDelegate>

@property(strong, nonatomic) BLMNativeAdManager *nativeAdManager;
@property(strong, nonatomic) BLMNativeAd *nativeAd;
@property(nonatomic) BOOL autoShow;

@end

@implementation NativeViewController

- (void)viewDidLoad {
    [super viewDidLoad];
    self.navigationItem.title = @"原生广告";
}

- (IBAction)loadNativeAd:(id)sender {
    [self loadNativeAdAutoShow:NO];
}

- (IBAction)showNativeAd:(id)sender {
    if (!self.nativeAd) {
        [self.view makeToast:@"广告未加载成功"];
    } else if (!self.nativeAd.isValid) {
        [self.view makeToast:@"广告无效，请重新加载"];
    } else {
        [self.view addSubview:self.nativeAd.view];
    }
}

- (IBAction)loadAndShowNativeAd:(id)sender {
    [self loadNativeAdAutoShow:YES];
}

- (void)loadNativeAdAutoShow:(BOOL)autoShow {
    self.autoShow = autoShow;
    
    self.nativeAdManager = [[BLMNativeAdManager alloc] initWithUnitId:@"n1"];
    self.nativeAdManager.delegate = self;
    CGFloat width = self.view.width - 40;
    CGFloat height = 0;
    [self.nativeAdManager loadAdWithWidth:width height:height count:1];
}

#pragma mark - BLMNativeAdDelegate

- (void)nativeAdDidLoad:(NSArray<BLMNativeAd *> *)ads {
    NSLog(@"%s", __FUNCTION__);
    [self.view makeToast:@"广告加载成功"];
    self.nativeAd = ads[0];
}

- (void)nativeAdFailToLoadWithError:(NSError *)error {
    NSLog(@"%s %@", __FUNCTION__, error);
    [self.view makeToast:[NSString stringWithFormat: @"%@", error]];
}

- (void)nativeAdRenderSuccess:(BLMNativeAd *)ad {
    NSLog(@"%s", __FUNCTION__);
    ad.controller = self; // 如果未设置 controller，部分广告点击不会跳转
    ad.view.x = (self.view.width - ad.view.width) / 2;
    ad.view.y = self.view.height - ad.view.height - 40;
    
    if (self.autoShow) {
        [self.view addSubview:self.nativeAd.view];
    }
}

- (void)nativeAdWillVisible:(BLMNativeAd *)ad {
    NSLog(@"%s", __FUNCTION__);
}

- (void)nativeAdDidClick:(BLMNativeAd *)ad {
    NSLog(@"%s", __FUNCTION__);
}

- (void)nativeAdDidClose:(BLMNativeAd *)ad {
    NSLog(@"%s", __FUNCTION__);
}

- (void)nativeAdDidFail:(BLMNativeAd *)ad error:(NSError *)error {
    NSLog(@"%s %@", __FUNCTION__, error);
    [self.view makeToast:[NSString stringWithFormat: @"%@", error]];
}

@end
