//
//  SplashViewController.m
//  BLMAdDemo
//
//  Created by BloomAd on 2022/7/4.
//

#import "SplashViewController.h"
#import <BLMAdSdk/BLMAdSdk.h>
#import <Toast/Toast.h>
#import "UIView+Utils.h"

static const NSInteger kBottomViewHeight = 120;

@interface SplashViewController () <BLMSplashAdDelegate>

@property(strong, nonatomic) BLMSplashAdManager *splashAdManager;
@property(weak, nonatomic) BLMSplashAd *splashAd;
@property(nonatomic) BOOL autoShow;

@property(strong, nonatomic) UIView *placeholderView;
@property(strong, nonatomic) UIView *bottomView;

@end

@implementation SplashViewController

- (void)viewDidLoad {
    [super viewDidLoad];
    self.navigationItem.title = @"开屏广告";
}

- (IBAction)loadSplashAd:(id)sender {
    [self loadSplashAdAutoShow:NO];
}

- (IBAction)showSplashAd:(id)sender {
    if (!self.splashAd) {
        [self.view makeToast:@"广告未加载成功"];
    } else if (!self.splashAd.isValid) {
        [self.view makeToast:@"广告无效，请重新加载"];
    } else {
        self.placeholderView = [self createPlaceholderView];
        [self.view.window addSubview:self.placeholderView];
        [self.splashAd showAdInView:self.placeholderView withBottomView:self.bottomView];
    }
}

- (IBAction)loadAndShowSplashAd:(id)sender {
    self.placeholderView = [self createPlaceholderView];
    [self.view.window addSubview:self.placeholderView];
    [self loadSplashAdAutoShow:YES];
}

- (void)loadSplashAdAutoShow:(BOOL)autoShow {
    self.autoShow = autoShow;
    
    self.splashAdManager = [[BLMSplashAdManager alloc] initWithUnitId:@"s1"];
    self.splashAdManager.delegate = self;
    CGSize screenSize = [UIScreen mainScreen].bounds.size;
    [self.splashAdManager loadAdWithWidth:screenSize.width height:screenSize.height - kBottomViewHeight];
}

- (UIView *)createPlaceholderView {
    UIView *placeholderView = [[UIView alloc] initWithFrame:[UIScreen mainScreen].bounds];
    placeholderView.backgroundColor = [UIColor whiteColor];
    [placeholderView addSubview:self.bottomView];
    return placeholderView;
}

- (UIView *)bottomView {
    if (!_bottomView) {
        CGSize screenSize = [UIScreen mainScreen].bounds.size;
        _bottomView = [[UIView alloc] initWithFrame:CGRectMake(0, screenSize.height - kBottomViewHeight, screenSize.width, kBottomViewHeight)];
        UIImageView *imageView = [[UIImageView alloc] initWithImage:[UIImage imageNamed:@"slogan"]];
        imageView.frame = CGRectMake(20, 20, _bottomView.width - 40, kBottomViewHeight - 40);
        imageView.contentMode = UIViewContentModeScaleAspectFit;
        [_bottomView addSubview:imageView];
    }
    return _bottomView;
}

#pragma mark - BLMSplashAdDelegate

- (void)splashAdDidLoad:(BLMSplashAd *)ad {
    NSLog(@"%s", __FUNCTION__);
    [self.view makeToast:@"广告加载成功"];
    self.splashAd = ad;

    if (self.autoShow) {
        [self.splashAd showAdInView:self.placeholderView withBottomView:self.bottomView];
    }
}

- (void)splashAdFailToLoadWithError:(NSError *)error {
    NSLog(@"%s %@", __FUNCTION__, error);
    [self.view makeToast:[NSString stringWithFormat: @"%@", error]];
    
    [self.placeholderView removeFromSuperview];
    [self.splashAdManager cancelAll];
}

- (void)splashAdWillVisible:(BLMSplashAd *)ad {
    NSLog(@"%s", __FUNCTION__);
}

- (void)splashAdDidClick:(BLMSplashAd *)ad {
    NSLog(@"%s", __FUNCTION__);
}

- (void)splashAdDidClose:(BLMSplashAd *)ad {
    NSLog(@"%s", __FUNCTION__);
    
    [self.placeholderView removeFromSuperview];
    [self.splashAdManager cancelAll];
}

- (void)splashAdDidFail:(BLMSplashAd *)ad error:(NSError *)error {
    NSLog(@"%s %@", __FUNCTION__, error);
    [self.view makeToast:[NSString stringWithFormat: @"%@", error]];
    
    [self.placeholderView removeFromSuperview];
    [self.splashAdManager cancelAll];
}

@end
